@@ -9,10 +9,11 @@ import sys
 import subprocess
 from threading import Thread, Lock
 from queue import Queue
-from typing import List, Optional
+from typing import List, Optional, Tuple, Any
 
 from subprocess_connection import Message
-from .lib import Entry
+
+from plover_search_translation.lib import Entry
 
 class Process:
 	"""
@@ -33,6 +34,10 @@ class Process:
 		self._message.call.picked=lambda entry: self.on_pick(entry)
 
 		self._message.func.search=lambda query: self.on_search(query)
+		self._message.func.lookup=lambda outline: self.lookup(outline)
+
+		self._message.call.save_column_width=lambda value: self.save_column_width(value)
+		self._message.func.get_column_width=lambda: self.get_column_width()
 
 		self._message.start()
 
@@ -67,6 +72,15 @@ class Process:
 	def on_search(self, query: str)->List[Entry]:
 		raise NotImplementedError
 
+	def lookup(self, outline: Tuple[str, ...])->Optional[str]:
+		raise NotImplementedError
+
+	def save_column_width(self, value: Any)->None:
+		raise NotImplementedError
+
+	def get_column_width(self)->Any:
+		raise NotImplementedError
+
 
 
 
@@ -85,7 +99,13 @@ if __name__=="__main__":
 				Entry("a", "b", ("c", "d")),
 				Entry("e", "f", ("g", "h")),
 				]
+	def lookup(outline: Tuple[str, ...])->Optional[str]:
+		return None
 	process.on_search=on_search  # type: ignore
+	process.lookup=lookup  # type: ignore
+
+	process.get_column_width=lambda: None  # type: ignore
+	process.save_column_width=lambda value: None  # type: ignore
 
 	process.open_dialog()
 
