@@ -7,10 +7,11 @@ and also Plover's extension plugin entry point.
 
 from __future__ import annotations
 
+import traceback
 import typing
 if typing.TYPE_CHECKING:
 	from plover.engine import StenoEngine  # type: ignore
-	from typing import Optional, List, Dict, Union
+	from typing import Optional, List, Dict, Union, Tuple, Any
 	from .lib import Entry
 	from .dictionary import Dictionary
 
@@ -25,6 +26,15 @@ class Manager:
 		self._process: Optional[Process]=None
 		self._dictionary: Optional[Dictionary]=None
 
+		from plover import config  # type: ignore
+		config.Config._OPTIONS["plover_search_translation_column_width"]=config.json_option(
+			"plover_search_translation_column_width",
+			lambda config, key: None,
+			"Plugin: Search Translation",
+			"column_width",
+			lambda config, key, value: value
+			)
+
 	def start(self):
 		"""
 		Called when Plover starts (or the extension plugin is enabled)
@@ -36,8 +46,12 @@ class Manager:
 		self._process.on_add=self.on_add
 		self._process.on_remove=self.on_remove
 		self._process.on_search=self.on_search
+		self._process.lookup=self.lookup
 		self._process.show_error=self.show_error
 
+		self._process.get_column_width=self.get_column_width
+		self._process.save_column_width=self.save_column_width
+
 		self._dictionary=None
 
 		global instance
@@ -56,6 +70,11 @@ class Manager:
 		self._process.exit()
 		self._process=None
 
+	def save_column_width(self, value: Any)->None:
+		self._engine["plover_search_translation_column_width"]=value
+
+	def get_column_width(self)->Any:
+		return self._engine["plover_search_translation_column_width"]
 
 	def show_error(self, message: str)->None:
 		from plover import log  # type: ignore
@@ -93,7 +112,6 @@ class Manager:
 				#self._engine._trigger_hook('stroked', stroke)
 
 		except:
-			import traceback
 			traceback.print_exc()
 
 	def on_add(self, entry: Entry)->None:
@@ -110,6 +128,15 @@ class Manager:
 		assert self._dictionary is not None
 		return self._dictionary.search(query)
 
+	def lookup(self, outline: Tuple[str, ...])->Optional[str]:
+		assert outline
+		try:
+			return self._engine.dictionaries.raw_lookup(outline)
+		except:
+			print(">>", outline)
+			traceback.print_exc()
+			return None
+
 	def close_window(self)->None:
 		assert self._process
 		assert self._dictionary is not None
